# python-mediaserver-processor
Image processor for mediaservers that receive items that have to be resized or reformatted to be used in a source set.

This is a work in progress and the final product may differ slightly from the product that you can currently use.
